@@ -161,7 +161,11 @@ enum { MSG_QUEUE_HEADER=FIRST_REMOTE_MSG_ID,
 		 MSG_COMPARE_SPY,
 		 MSG_COMPARE_TALK,
 
+		//### jesse 2021 ###//
 		 MSG_U_CARA_COPY_ROUTE,
+		 MSG_COMPARE_CRC,
+		 MSG_U_SHIP_COPY_ROUTE,
+		 MSG_FIRM_REQ_BUILDER,
 
 		 LAST_REMOTE_MSG_ID			// keep this item last
 	  };
@@ -227,6 +231,7 @@ public:
 	void	ship_del_stop();
 	void	ship_change_mode();
 	void	ship_selected();
+	void	ship_copy_route();
 	void	god_cast();
 	void	change_spy_nation();
 	void	notify_cloaked_nation();
@@ -305,8 +310,10 @@ public:
 	 //##### trevor 30/9 #######//
 
 	void	compare_remote_object();
+	void	compare_remote_crc();
 
 	void	caravan_copy_route();
+	void	firm_request_builder();
 };
 
 //----------- Define class Remote -----------//
