@@ -177,6 +177,9 @@ static MsgProcessFP msg_process_function_array[] =
 	&RemoteMsg::compare_remote_object,
 
 	&RemoteMsg::caravan_copy_route,
+	&RemoteMsg::compare_remote_crc,
+	&RemoteMsg::ship_copy_route,
+	&RemoteMsg::firm_request_builder,
 };
 
 //---------- Declare static functions ----------//
@@ -1382,6 +1385,36 @@ void RemoteMsg::ship_change_mode()
 // ------- End of function RemoteMsg::ship_change_mode ------//
 
 
+// ------- Begin of function RemoteMsg::ship_copy_route ------//
+void RemoteMsg::ship_copy_route()
+{
+	err_when( id != MSG_U_SHIP_COPY_ROUTE);
+	// packet structure : <unit recno> <copy unit recno>
+	short *shortPtr = (short *)data_buf;
+	short unitCount= 2;
+	validate_selected_unit_array(shortPtr, unitCount);
+
+	if( unitCount > 0)
+	{
+		Unit *unitPtr = unit_array[*shortPtr];
+		UnitMarine *shipPtr;
+		if( unitPtr->unit_id != UNIT_VESSEL )
+		{
+			err_here();
+		}
+		else
+		{
+#ifdef DEBUG_LONG_LOG
+			long_log->printf("ship %d copy route from %d\n", shortPtr[0], shortPtr[1]);
+#endif
+			shipPtr = (UnitMarine *)unitPtr;
+			shipPtr->copy_route(shortPtr[1], COMMAND_REMOTE);
+		}
+	}
+}
+// ------- End of function RemoteMsg::ship_copy_route ------//
+
+
 // ------- Begin of function RemoteMsg::change_spy_nation ------//
 void RemoteMsg::change_spy_nation()
 {
@@ -2866,10 +2899,8 @@ void	RemoteMsg::compare_remote_object()
 	err_when( id < MSG_COMPARE_NATION || id > MSG_COMPARE_TALK );
 
 	// ###### patch begin Gilbert 20/1 #######//
-	if( (remote.sync_test_level & 2) && (remote.sync_test_level >= 0)
-		&& crc_store.compare_remote(id, data_buf) )
+	if( crc_store.compare_remote(id, data_buf) )
 	{
-		remote.sync_test_level = ~2;	// signal error encountered
 		if( sys.debug_session )
 			err.run( _("Multiplayer Object Sync Error") );
 	}
@@ -2878,6 +2909,20 @@ void	RemoteMsg::compare_remote_object()
 //------- End of function RemoteMsg::compare_remote_object -------//
 
 
+//------- Begin of function RemoteMsg::compare_remote_crc -------//
+void RemoteMsg::compare_remote_crc()
+{
+	err_when( id != MSG_COMPARE_CRC );
+
+	if( (remote.sync_test_level & 2) && (remote.sync_test_level >= 0)
+		&& crc_store.compare_frame(data_buf) )
+	{
+		remote.sync_test_level = ~2;	// signal error encountered
+	}
+}
+//------- End of function RemoteMsg::compare_remote_crc -------//
+
+
 //------- Begin of function RemoteMsg::unit_add_way_point -------//
 void RemoteMsg::unit_add_way_point()
 {
@@ -2943,3 +2988,17 @@ void RemoteMsg::player_quit()
 		news_array.multi_quit_game(*shortPtr);
 }
 // ------- End of function RemoteMsg::player_quit ---------//
+
+
+// ------- Begin of function RemoteMsg::firm_request_builder ---------//
+void RemoteMsg::firm_request_builder()
+{
+	err_when( id != MSG_FIRM_REQ_BUILDER);
+	// packet structure : <firm recno>
+	short *shortPtr = (short *)data_buf;
+	if( validate_firm(*shortPtr) )
+	{
+		firm_array[*shortPtr]->send_idle_builder_here(COMMAND_REMOTE);
+	}
+}
+// ------- End of function RemoteMsg::firm_request_builder ---------//
