@@ -177,8 +177,19 @@ int Spy::get_loc(int& xLoc, int& yLoc)
 		case SPY_MOBILE:
 			if( !unit_array.is_deleted(spy_place_para) )
 			{
-				xLoc = unit_array[spy_place_para]->next_x_loc();
-				yLoc = unit_array[spy_place_para]->next_y_loc();
+				Unit* unitPtr = unit_array[spy_place_para];
+
+				if( unitPtr->unit_mode == UNIT_MODE_ON_SHIP )
+				{
+					Unit* shipPtr = unit_array[unitPtr->unit_mode_para];
+					xLoc = shipPtr->next_x_loc();
+					yLoc = shipPtr->next_y_loc();
+				}
+				else
+				{
+					xLoc = unitPtr->next_x_loc();
+					yLoc = unitPtr->next_y_loc();
+				}
 				return 1;
 			}
 			break;
@@ -211,8 +222,6 @@ int Spy::spy_place_nation_recno()
 //
 void Spy::next_day()
 {
-	SpyArrayLock arrayLock;
-
 	//------- pay expenses --------//
 
 	pay_expense();
@@ -269,6 +278,7 @@ void Spy::next_day()
 
 	if( true_nation_recno == nation_array.player_recno )
 	{
+		Unit* unitPtr = unit_array[spy_place_para];
 		if( spy_place == SPY_TOWN )
 		{
 			Town* townPtr = town_array[spy_place_para];
@@ -279,6 +289,31 @@ void Spy::next_day()
 			Firm* firmPtr = firm_array[spy_place_para];
 			world.visit( firmPtr->loc_x1, firmPtr->loc_y1, firmPtr->loc_x2, firmPtr->loc_y2, EXPLORE_RANGE-1 );
 		}
+		else if( unitPtr->unit_mode == UNIT_MODE_CONSTRUCT )
+		{
+			Firm* firmPtr = firm_array[unitPtr->unit_mode_para];
+			world.visit( firmPtr->loc_x1, firmPtr->loc_y1, firmPtr->loc_x2, firmPtr->loc_y2, EXPLORE_RANGE-1 );
+		}
+		else if( unitPtr->unit_mode == UNIT_MODE_ON_SHIP )
+		{
+			Unit* shipPtr = unit_array[unitPtr->unit_mode_para];
+			if( shipPtr->unit_mode == UNIT_MODE_IN_HARBOR )
+			{
+				Firm* firmPtr = firm_array[shipPtr->unit_mode_para];
+				world.visit( firmPtr->loc_x1, firmPtr->loc_y1, firmPtr->loc_x2, firmPtr->loc_y2, EXPLORE_RANGE-1 );
+			}
+			else
+			{
+				int xloc1 = shipPtr->next_x_loc();
+				int yloc1 = shipPtr->next_y_loc();
+				int xloc2 = xloc1+shipPtr->sprite_info->loc_width-1;
+				int yloc2 = yloc1+shipPtr->sprite_info->loc_height-1;
+				int range = unit_res[shipPtr->unit_id]->visual_range;
+
+				world.unveil(xloc1, yloc1, xloc2, yloc2);
+				world.visit(xloc1, yloc1, xloc2, yloc2, range);
+			}
+		}
 	}
 
 	//---------- debug code -----------//
@@ -332,8 +367,6 @@ void Spy::next_day()
 //
 void Spy::process_town_action()
 {
-	SpyArrayLock arrayLock;
-
 	Town* townPtr = town_array[spy_place_para];
 
 	if( action_mode == SPY_SOW_DISSENT )
@@ -371,8 +404,6 @@ void Spy::process_town_action()
 //
 void Spy::process_firm_action()
 {
-	SpyArrayLock arrayLock;
-
 	Firm* firmPtr = firm_array[spy_place_para];
 
 	//---------- Sow Dissent ----------//
@@ -484,8 +515,6 @@ int Spy::can_sabotage()
 //
 void Spy::get_killed(int dispNews)
 {
-	SpyArrayLock arrayLock;
-
 	//-------- add news --------//
 
 	if( true_nation_recno == nation_array.player_recno ||		// the player's spy is killed
@@ -721,8 +750,6 @@ void Spy::change_loyalty(int changeAmt)
 //
 int Spy::think_betray()
 {
-	SpyArrayLock arrayLock;
-
 	if( spy_loyalty >= UNIT_BETRAY_LOYALTY )		// you when unit is
 		return 0;
 
@@ -756,8 +783,6 @@ int Spy::think_betray()
 //
 void Spy::drop_spy_identity()
 {
-	SpyArrayLock arrayLock;
-
 	if( spy_place == SPY_FIRM )
 	{
 		Firm* firmPtr = firm_array[spy_place_para];
@@ -809,8 +834,6 @@ void Spy::drop_spy_identity()
 //
 void Spy::change_true_nation(int newNationRecno)
 {
-	SpyArrayLock arrayLock;
-
 	err_when( nation_array.is_deleted(newNationRecno) );
 
 	true_nation_recno = newNationRecno;
@@ -835,8 +858,6 @@ void Spy::change_true_nation(int newNationRecno)
 //
 void Spy::change_cloaked_nation(int newNationRecno)
 {
-	SpyArrayLock arrayLock;
-
 	if( newNationRecno == cloaked_nation_recno )
 		return;
 
@@ -898,8 +919,6 @@ int Spy::can_change_cloaked_nation(int newNationRecno)
 //
 int Spy::capture_firm()
 {
-	SpyArrayLock arrayLock;
-
 	if( spy_place != SPY_FIRM )
 		return 0;
 
@@ -1026,8 +1045,6 @@ int Spy::capture_firm()
 //
 int Spy::mobilize_spy()
 {
-	SpyArrayLock arrayLock;
-
 	switch( spy_place )
 	{
 		case SPY_TOWN:
@@ -1056,8 +1073,6 @@ int Spy::mobilize_spy()
 //
 int Spy::mobilize_town_spy(int decPop)
 {
-	SpyArrayLock arrayLock;
-
 	err_when( spy_place != SPY_TOWN );
 
 	if( spy_place != SPY_TOWN )
@@ -1090,8 +1105,6 @@ int Spy::mobilize_town_spy(int decPop)
 //
 int Spy::mobilize_firm_spy()
 {
-	SpyArrayLock arrayLock;
-
 	err_when( spy_place != SPY_FIRM );
 
 	if( spy_place != SPY_FIRM )
@@ -1143,8 +1156,6 @@ int Spy::mobilize_firm_spy()
 //
 void Spy::think_become_king()
 {
-	SpyArrayLock arrayLock;
-
 	err_when( spy_place != SPY_MOBILE );		// it must be mobile
 
 	int hisNationPower = nation_array[cloaked_nation_recno]->overall_rating;
